public class Source
{
  /**
   * Javadoc for method1
   * Another line of javadoc
   */
  @Version("1.1"
// line comment
// line comment
  )
  @Deprecated
  public static List< ? extends Serializable > method1() 
  {
    // line comment
    // line comment
  }
  
  /**
   * Javadoc for method2
   * Another line of javadoc
   */    
  @Version("1.2"
// line comment
// line comment
  )
  @Deprecated
  protected final T method2() throws Exception
  {
    
  }
}

private enum Source1
{
}
